package org.sersar.cayenne;

import java.util.Collection;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Level;
import org.objectstyle.cayenne.DataObject;
import org.objectstyle.cayenne.DataRow;
import org.objectstyle.cayenne.ObjectId;
import org.objectstyle.cayenne.access.DataContextDelegate;
import org.objectstyle.cayenne.access.DataDomain;
import org.objectstyle.cayenne.access.DataNode;
import org.objectstyle.cayenne.access.ObjectStore;
import org.objectstyle.cayenne.access.OperationObserver;
import org.objectstyle.cayenne.access.QueryEngine;
import org.objectstyle.cayenne.access.ResultIterator;
import org.objectstyle.cayenne.access.Transaction;
import org.objectstyle.cayenne.map.DataMap;
import org.objectstyle.cayenne.map.EntityResolver;
import org.objectstyle.cayenne.map.ObjEntity;
import org.objectstyle.cayenne.query.GenericSelectQuery;
import org.objectstyle.cayenne.query.Query;
import org.objectstyle.cayenne.query.SelectQuery;

/**
 * @author Takahiro MATSUNAGA
 */
public interface S2DataContext {

    public void commitChanges();

    public void commitChanges(Level logLevel);

    public DataObject createAndRegisterNewObject(Class objectClass);

    public DataObject createAndRegisterNewObject(String objEntityName);

    public DataRow currentSnapshot(DataObject anObject);

    public Collection deletedObjects();

    public void deleteObject(DataObject anObject);

    public Collection getDataMaps();

    public DataContextDelegate getDelegate();

    public EntityResolver getEntityResolver();

    public ObjectStore getObjectStore();

    public QueryEngine getParent();

    public DataDomain getParentDataDomain();

    public boolean hasChanges();

    public void invalidateObjects(Collection dataObjects);

    public boolean isTransactionEventsEnabled();

    public boolean isUsingSharedSnapshotCache();

    public boolean isValidatingObjectsOnCommit();

    public List localObjects(List objects);

    public DataNode lookupDataNode(DataMap dataMap);

    public Collection modifiedObjects();

    public Collection newObjects();

    public DataObject objectFromDataRow(Class objectClass, DataRow dataRow, boolean refresh);

    public List objectsFromDataRows(Class objectClass, List dataRows, boolean refresh, boolean resolveInheritanceHierarchy);

    public List objectsFromDataRows(ObjEntity entity, List dataRows, boolean refresh, boolean resolveInheritanceHierarchy);

    public ResultIterator performIteratedQuery(GenericSelectQuery query) throws CayenneRuntimeException;

    public int[] performNonSelectingQuery(Query query);

    public int[] performNonSelectingQuery(String queryName);

    public int[] performNonSelectingQuery(String queryName, Map parameters);

    public void performQueries(Collection queries, OperationObserver observer);

    public void performQueries(Collection queries, OperationObserver resultConsumer, Transaction transaction);

    public List performQuery(GenericSelectQuery query);

    public List performQuery(String queryName, boolean refresh);

    public List performQuery(String queryName, Map parameters, boolean refresh);

    public void prefetchRelationships(SelectQuery query, List objects);

    public DataObject refetchObject(ObjectId oid);

    public DataObject registeredObject(ObjectId oid);

    public void registerNewObject(DataObject dataObject);

    public void rollbackChanges();

    public void setDelegate(DataContextDelegate delegate);

    public void setParent(QueryEngine parent);

    public void setTransactionEventsEnabled(boolean flag);

    public void setValidatingObjectsOnCommit(boolean flag);

    public void unregisterObjects(Collection dataObjects);

}
