package org.sersar.cayenne.impl;

import java.util.Collection;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Level;
import org.objectstyle.cayenne.CayenneException;
import org.objectstyle.cayenne.DataObject;
import org.objectstyle.cayenne.DataRow;
import org.objectstyle.cayenne.ObjectId;
import org.objectstyle.cayenne.access.DataContext;
import org.objectstyle.cayenne.access.DataContextDelegate;
import org.objectstyle.cayenne.access.DataDomain;
import org.objectstyle.cayenne.access.DataNode;
import org.objectstyle.cayenne.access.ObjectStore;
import org.objectstyle.cayenne.access.OperationObserver;
import org.objectstyle.cayenne.access.QueryEngine;
import org.objectstyle.cayenne.access.ResultIterator;
import org.objectstyle.cayenne.access.Transaction;
import org.objectstyle.cayenne.map.DataMap;
import org.objectstyle.cayenne.map.EntityResolver;
import org.objectstyle.cayenne.map.ObjEntity;
import org.objectstyle.cayenne.query.GenericSelectQuery;
import org.objectstyle.cayenne.query.Query;
import org.objectstyle.cayenne.query.SelectQuery;
import org.sersar.cayenne.CayenneRuntimeException;
import org.sersar.cayenne.S2DataContext;

/**
 * @author Takahiro MATSUNAGA
 * @see S2DataContext
 */
public class S2DataContextImpl implements S2DataContext {

    private DataContext dataContext_;

    /**
     * @param dataContext
     */
    public S2DataContextImpl(DataContext dataContext) {
        dataContext_ = dataContext;
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#commitChanges()
     */
    public void commitChanges() {
        dataContext_.commitChanges();
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#commitChanges(org.apache.log4j.Level)
     */
    public void commitChanges(Level logLevel) {
        dataContext_.commitChanges(logLevel);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#createAndRegisterNewObject(java.lang.Class)
     */
    public DataObject createAndRegisterNewObject(Class objectClass) {
        return dataContext_.createAndRegisterNewObject(objectClass);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#createAndRegisterNewObject(java.lang.String)
     */
    public DataObject createAndRegisterNewObject(String objEntityName) {
        return dataContext_.createAndRegisterNewObject(objEntityName);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#currentSnapshot(org.objectstyle.cayenne.DataObject)
     */
    public DataRow currentSnapshot(DataObject anObject) {
        return dataContext_.currentSnapshot(anObject);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#deletedObjects()
     */
    public Collection deletedObjects() {
        return dataContext_.deletedObjects();
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#deleteObject(org.objectstyle.cayenne.DataObject)
     */
    public void deleteObject(DataObject dataObject) {
        dataContext_.deleteObject(dataObject); 
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#getDataMaps()
     */
    public Collection getDataMaps() {
        return dataContext_.getDataMaps();
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#getDelegate()
     */
    public DataContextDelegate getDelegate() {
        return dataContext_.getDelegate();
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#getEntityResolver()
     */
    public EntityResolver getEntityResolver() {
        return dataContext_.getEntityResolver();
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#getObjectStore()
     */
    public ObjectStore getObjectStore() {
        return dataContext_.getObjectStore();
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#getParent()
     */
    public QueryEngine getParent() {
        return dataContext_.getParent();
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#getParentDataDomain()
     */
    public DataDomain getParentDataDomain() {
        return dataContext_.getParentDataDomain();
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#hasChanges()
     */
    public boolean hasChanges() {
        return dataContext_.hasChanges();
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#invalidateObjects(java.util.Collection)
     */
    public void invalidateObjects(Collection dataObjects) {
        dataContext_.invalidateObjects(dataObjects);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#isTransactionEventsEnabled()
     */
    public boolean isTransactionEventsEnabled() {
        return dataContext_.isTransactionEventsEnabled();
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#isUsingSharedSnapshotCache()
     */
    public boolean isUsingSharedSnapshotCache() {
        return dataContext_.isUsingSharedSnapshotCache();
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#isValidatingObjectsOnCommit()
     */
    public boolean isValidatingObjectsOnCommit() {
        return dataContext_.isValidatingObjectsOnCommit();
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#localObjects(java.util.List)
     */
    public List localObjects(List objects) {
        return dataContext_.localObjects(objects);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#lookupDataNode(org.objectstyle.cayenne.map.DataMap)
     */
    public DataNode lookupDataNode(DataMap dataMap) {
        return dataContext_.lookupDataNode(dataMap);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#modifiedObjects()
     */
    public Collection modifiedObjects() {
        return dataContext_.modifiedObjects();
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#newObjects()
     */
    public Collection newObjects() {
        return dataContext_.newObjects();
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#objectFromDataRow(java.lang.Class, org.objectstyle.cayenne.DataRow, boolean)
     */
    public DataObject objectFromDataRow(Class objectClass, DataRow dataRow, boolean refresh) {
        return dataContext_.objectFromDataRow(objectClass, dataRow, refresh);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#objectsFromDataRows(java.lang.Class, java.util.List, boolean, boolean)
     */
    public List objectsFromDataRows(Class objectClass, List dataRows, boolean refresh, boolean resolveInheritanceHierarchy) {
        return dataContext_.objectsFromDataRows(objectClass, dataRows, refresh, resolveInheritanceHierarchy);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#objectsFromDataRows(org.objectstyle.cayenne.map.ObjEntity, java.util.List, boolean, boolean)
     */
    public List objectsFromDataRows(ObjEntity entity, List dataRows, boolean refresh, boolean resolveInheritanceHierarchy) {
        return dataContext_.objectsFromDataRows(entity, dataRows, refresh, resolveInheritanceHierarchy);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#performIteratedQuery(org.objectstyle.cayenne.query.GenericSelectQuery)
     */
    public ResultIterator performIteratedQuery(GenericSelectQuery query) throws CayenneRuntimeException {
        try {
            return dataContext_.performIteratedQuery(query);
        } catch (CayenneException e) {
            throw new CayenneRuntimeException(e);
        }
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#performNonSelectingQuery(org.objectstyle.cayenne.query.Query)
     */
    public int[] performNonSelectingQuery(Query query) {
        return dataContext_.performNonSelectingQuery(query);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#performNonSelectingQuery(java.lang.String)
     */
    public int[] performNonSelectingQuery(String queryName) {
        return dataContext_.performNonSelectingQuery(queryName);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#performNonSelectingQuery(java.lang.String, java.util.Map)
     */
    public int[] performNonSelectingQuery(String queryName, Map parameters) {
        return dataContext_.performNonSelectingQuery(queryName, parameters);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#performQueries(java.util.Collection, org.objectstyle.cayenne.access.OperationObserver)
     */
    public void performQueries(Collection queries, OperationObserver observer) {
        dataContext_.performQueries(queries, observer);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#performQueries(java.util.Collection, org.objectstyle.cayenne.access.OperationObserver, org.objectstyle.cayenne.access.Transaction)
     */
    public void performQueries(Collection queries, OperationObserver resultConsumer, Transaction transaction) {
        dataContext_.performQueries(queries, resultConsumer, transaction);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#performQuery(org.objectstyle.cayenne.query.GenericSelectQuery)
     */
    public List performQuery(GenericSelectQuery query) {
        return dataContext_.performQuery(query);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#performQuery(java.lang.String, boolean)
     */
    public List performQuery(String queryName, boolean refresh) {
        return dataContext_.performQuery(queryName, refresh);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#performQuery(java.lang.String, java.util.Map, boolean)
     */
    public List performQuery(String queryName, Map parameters, boolean refresh) {
        return dataContext_.performQuery(queryName, parameters, refresh);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#prefetchRelationships(org.objectstyle.cayenne.query.SelectQuery, java.util.List)
     */
    public void prefetchRelationships(SelectQuery query, List objects) {
        dataContext_.prefetchRelationships(query, objects);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#refetchObject(org.objectstyle.cayenne.ObjectId)
     */
    public DataObject refetchObject(ObjectId oid) {
        return dataContext_.refetchObject(oid);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#registeredObject(org.objectstyle.cayenne.ObjectId)
     */
    public DataObject registeredObject(ObjectId oid) {
        return dataContext_.registeredObject(oid);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#registerNewObject(org.objectstyle.cayenne.DataObject)
     */
    public void registerNewObject(DataObject dataObject) {
        dataContext_.registerNewObject(dataObject);
    }

    /* ( Javadoc)
     * @see org.sersar.cayenne.S2DataContext#rollbackChanges()
     */
    public void rollbackChanges() {
        dataContext_.rollbackChanges();
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#setDelegate(org.objectstyle.cayenne.access.DataContextDelegate)
     */
    public void setDelegate(DataContextDelegate delegate) {
        dataContext_.setDelegate(delegate);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#setParent(org.objectstyle.cayenne.access.QueryEngine)
     */
    public void setParent(QueryEngine parent) {
        dataContext_.setParent(parent);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#setTransactionEventsEnabled(boolean)
     */
    public void setTransactionEventsEnabled(boolean flag) {
        dataContext_.setTransactionEventsEnabled(flag);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#setValidatingObjectsOnCommit(boolean)
     */
    public void setValidatingObjectsOnCommit(boolean flag) {
        dataContext_.setValidatingObjectsOnCommit(flag);
    }

    /* (Javadoc Ȃ)
     * @see org.sersar.cayenne.S2DataContext#unregisterObjects(java.util.Collection)
     */
    public void unregisterObjects(Collection dataObjects) {
        dataContext_.unregisterObjects(dataObjects);
    }

}
